/* Copyright (C) 1997 Bjoern Beutel. */

/* Description. =============================================================*/

/* Manages the transmit process from Malaga. */

/* Functions. ===============================================================*/

extern void init_transmit( void );
/* Initialise this module. */

extern void terminate_transmit( void );
/* Terminate this module. */

/* Commands. ================================================================*/

extern command_t transmit_cmd_option;
/* Set the command line to start the display process. */

extern command_t transmit_command;
/* Communicate with the transmit process. */

/* End of file. =============================================================*/
